pub struct AcknowledgementPipelineConfig {
pub ack_buffer_interval: Duration,
pub ack_grouping_capacity: usize,
pub ticket_ack_buffer_size: usize,
pub ack_out_buffer_size: usize,
pub ack_input_concurrency: Option<usize>,
pub ack_output_concurrency: Option<usize>,
}Expand description
Configuration for the acknowledgement processing pipeline.
Fields
ack_buffer_interval: DurationInterval for which to wait to buffer acknowledgements before sending them out.
Default is 200 ms.
ack_grouping_capacity: usizeInitial capacity when grouping outgoing acknowledgements.
If set too low, it causes additional reallocations in the outgoing acknowledgement processing pipeline.
The value should grow if ack_buffer_interval grows.
Default is 5.
ticket_ack_buffer_size: usizeCapacity of the incoming_ack MPSC channel carrying received acknowledgements
to the ticket-ack processing pipeline.
The previous hardcoded value of 1_000_000 pre-allocated ~MBs of ring buffer per node even
though real-world throughput rarely saturates more than a few thousand entries. Let the
50 ms sink timeouts (QUEUE_SEND_TIMEOUT) propagate backpressure instead.
The default is 50 000.
ack_out_buffer_size: usizeCapacity of the outgoing_ack MPSC channel carrying acknowledgements to be sent back
to the previous hop.
The default is 50 000. See ticket_ack_buffer_size for the
rationale on why this is smaller than the original hardcoded 1_000_000.
ack_input_concurrency: Option<usize>Maximum concurrency when processing incoming (received) acknowledgements.
None or Some(0) both fall back to a default of 10.
ack_output_concurrency: Option<usize>Maximum concurrency when processing outgoing (sent-back) acknowledgements.
None or Some(0) both fall back to a default of 10.